// File: gccDemo.c
// A simple C program
//
#include <avr/io.h>          // This contains I/O control register and port name definitions (DDRB, PORTB) etc.
//#include <avr/interrupt.h> // contains declaration for interrupt-related functions such as sei()
#include <inttypes.h>        // Contains C99 data types such as "uint8_t" etc
#include <stddef.h>          // contains definition for "NULL" etc
#include <stdbool.h>         // needed for "bool", "true", "false" etc


#include <lcd.h>             // Contains many lcd function declarations
#include <delay.h>           // Contains function declarations for a couple of home-written delay routines

// < > means look in "standard" locations for the file to #include - including any
// directories specified in the Project Configuration "Include Directories".
// lcd.h and delay.h are not "standard" header files, but the path to these files appears in the 
// "Include Directories" setting

// "" means look in local directory containing this .c file *first*, THEN in the "standard" locations
#include "pause.h"  

//#include <math.h>

// function declaration; ensures that references (calls) to this function 
// conform to the signature (correct return type, correct type ane number of arguments)
// We can put this in another .h file if we wanted to...
void somemethod(int); 


// this declaration says that myglobalvar is actually defined in another compilation unit;
// we're just using it in this file.
extern int myglobalvar;

// #define tells the preprocessor to assign a non-zero value to USE_LCD
#define USE_LCD

int main()			// every C program needs a "main"
{
    bool b = true;  // need to #include <stdbool.h> for bool datatype and true/false
    
    register char c; // polite request to ask the compiler to use a register to hold the value of the variable

    auto char d;    // auto is same as nothing; let the compiler decide where to store the variable d

    myglobalvar = 3; 

    int v = (int)NULL;   // NULL is defined in <stddef.h>; sets v to 0

    somemethod(100);    // dummy call to dummy function just to illustrate function declarations (above)

#ifdef USE_LCD  // only compile this code if USE_LCD is #defined (conditional compilation)
	lcd_init();
	lcd_clear();
	lcd_home();
    lcd_goto_xy(5,0);
 	lcd_print_string("hey");
#endif         // end of conditionally compiled code

    int8_t x=255;     // -128 to +127, but 255 is still an 8-bit value, so the compiler is OK with it
    // the actual value of x will be -1, since 255 means all bits are set

    lcd_goto_xy(0,1);
 	lcd_print_int8(x); // prints out the value of x as a signed 8-bit int


    DDRB = 0xFF;       // configure PORTB pins all as output

    while( true ) {     // loop forever
        for( uint8_t i=0; i<200; i++ ) {
            pause(100);
            PORTB = i;  // output the value of i to PORTB
        }
    }   
    
}

// dummy method ("function" in C terminology)
void somemethod(int x) {
    // do nothing
}





	

